@@ -1,6 +1,8 @@
-use std::fmt::{Display, Formatter};
+use std::{
+    borrow::{Borrow, Cow},
+    fmt::{Display, Formatter},
+};
 
-use crossterm::style::{StyledContent, Stylize};
 use similar::{ChangeTag, DiffableStr, TextDiff};
 
 use super::themes::Theme;
@@ -11,23 +13,24 @@ use super::themes::Theme;
 pub struct DrawDiff<'a> {
     old: &'a str,
     new: &'a str,
-    theme: Theme,
+    theme: &'a dyn Theme,
 }
 
-impl DrawDiff<'_> {
+impl<'input> DrawDiff<'input> {
     /// Make a new instance of the diff drawer
     ///
     /// # Examples
     ///
     /// ```
-    /// use termdiff::{arrows_theme, DrawDiff};
+    /// use termdiff::{ArrowsTheme, DrawDiff};
+    /// let theme = ArrowsTheme::default();
     /// assert_eq!(
     ///     format!(
     ///         "{}",
     ///         DrawDiff::new(
     ///             "The quick brown fox and\njumps over the sleepy dog",
     ///             "The quick red fox and\njumps over the lazy dog",
-    ///             arrows_theme()
+    ///             &theme
     ///         )
     ///     ),
     ///     "< left / > right
@@ -39,38 +42,38 @@ impl DrawDiff<'_> {
     /// );
     /// ```
     #[must_use]
-    pub const fn new<'a>(old: &'a str, new: &'a str, theme: Theme) -> DrawDiff<'a> {
+    pub fn new<'a>(old: &'a str, new: &'a str, theme: &'a dyn Theme) -> DrawDiff<'a> {
         DrawDiff { old, new, theme }
     }
 
-    fn highlight(&self, text: String, tag: ChangeTag) -> StyledContent<String> {
+    fn highlight(&self, text: &'input str, tag: ChangeTag) -> Cow<'input, str> {
         match tag {
-            ChangeTag::Equal => text.stylize(),
-            ChangeTag::Delete => (self.theme.highlight_delete)(text),
-            ChangeTag::Insert => (self.theme.highlight_insert)(text),
+            ChangeTag::Equal => text.into(),
+            ChangeTag::Delete => self.theme.highlight_delete(text),
+            ChangeTag::Insert => self.theme.highlight_insert(text),
         }
     }
 
-    fn format_line(&self, line: String, tag: ChangeTag) -> StyledContent<String> {
+    fn format_line(&self, line: &'input str, tag: ChangeTag) -> Cow<'input, str> {
         match tag {
-            ChangeTag::Equal => (self.theme.equal_content)(line),
-            ChangeTag::Delete => (self.theme.delete_content)(line),
-            ChangeTag::Insert => (self.theme.insert_line)(line),
+            ChangeTag::Equal => self.theme.equal_content(line),
+            ChangeTag::Delete => self.theme.delete_content(line),
+            ChangeTag::Insert => self.theme.insert_line(line),
         }
     }
 
-    fn prefix(&self, tag: ChangeTag) -> &str {
+    fn prefix(&self, tag: ChangeTag) -> Cow<'input, str> {
         match tag {
-            ChangeTag::Equal => &self.theme.equal_prefix,
-            ChangeTag::Delete => &self.theme.delete_prefix,
-            ChangeTag::Insert => &self.theme.insert_prefix,
+            ChangeTag::Equal => self.theme.equal_prefix(),
+            ChangeTag::Delete => self.theme.delete_prefix(),
+            ChangeTag::Insert => self.theme.insert_prefix(),
         }
     }
 }
 
 impl Display for DrawDiff<'_> {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        write!(f, "{}", self.theme.header)?;
+        write!(f, "{}", self.theme.header())?;
         let diff = TextDiff::from_lines(self.old, self.new);
 
         for op in diff.ops() {
@@ -79,24 +82,20 @@ impl Display for DrawDiff<'_> {
 
                 for (highlight, inline_change) in change.values() {
                     if *highlight {
-                        let highlighted = self
-                            .highlight(inline_change.to_string_lossy().to_string(), change.tag());
+                        let cow = inline_change.to_string_lossy();
+                        let highlighted = self.highlight(cow.borrow(), change.tag());
                         write!(
                             f,
                             "{}",
-                            self.format_line(highlighted.to_string(), change.tag())
+                            self.format_line(highlighted.borrow(), change.tag())
                         )?;
                     } else {
-                        write!(
-                            f,
-                            "{}",
-                            self.format_line((*inline_change).to_string(), change.tag())
-                        )?;
+                        write!(f, "{}", self.format_line(*inline_change, change.tag()))?;
                     }
                 }
 
                 if change.missing_newline() {
-                    write!(f, "{}", self.theme.line_end)?;
+                    write!(f, "{}", self.theme.line_end())?;
                 }
             }
         }
@@ -113,16 +112,15 @@ impl From<DrawDiff<'_>> for String {
 
 #[cfg(test)]
 mod test {
-    use super::{
-        super::themes::{arrows_color_theme, arrows_theme},
-        DrawDiff,
-    };
+    use super::DrawDiff;
+    use crate::{ArrowsColorTheme, ArrowsTheme};
 
     #[test]
     fn single_characters() {
         let old = "a\nb\nc";
         let new = "a\nc\n";
-        let actual: DrawDiff = DrawDiff::new(old, new, arrows_theme());
+        let theme = ArrowsTheme {};
+        let actual: DrawDiff = DrawDiff::new(old, new, &theme);
 
         assert_eq!(
             format!("{}", actual),
@@ -139,7 +137,8 @@ mod test {
     fn one_line() {
         let old = "adc";
         let new = "abc";
-        let actual: DrawDiff = DrawDiff::new(old, new, arrows_theme());
+        let theme = ArrowsTheme {};
+        let actual: DrawDiff = DrawDiff::new(old, new, &theme);
         assert_eq!(
             format!("{}", actual),
             "< left / > right
@@ -153,7 +152,8 @@ mod test {
     fn line_by_line() {
         let old = "The quick brown fox and\njumps over the sleepy dog";
         let new = "The quick red fox and\njumps over the lazy dog";
-        let actual: DrawDiff = DrawDiff::new(old, new, arrows_theme());
+        let theme = ArrowsTheme {};
+        let actual: DrawDiff = DrawDiff::new(old, new, &theme);
         assert_eq!(
             format!("{}", actual),
             "< left / > right
@@ -169,7 +169,7 @@ mod test {
     fn into_string() {
         let old = "The quick brown fox and\njumps over the sleepy dog";
         let new = "The quick red fox and\njumps over the lazy dog";
-        let actual: String = DrawDiff::new(old, new, arrows_theme()).into();
+        let actual: String = DrawDiff::new(old, new, &ArrowsTheme {}).into();
         assert_eq!(
             actual,
             "< left / > right
@@ -185,7 +185,8 @@ mod test {
     fn its_customisable() {
         let old = "The quick brown fox and\njumps over the sleepy dog";
         let new = "The quick red fox and\njumps over the lazy dog";
-        let actual: DrawDiff = DrawDiff::new(old, new, arrows_color_theme());
+        let theme = ArrowsColorTheme {};
+        let actual: DrawDiff = DrawDiff::new(old, new, &theme);
 
         assert_eq!(
             format!("{}", actual),
