@@ -3,11 +3,12 @@
 //! # Examples
 //!
 //! ```
-//! use termdiff::{arrows_theme, diff};
+//! use termdiff::{diff, ArrowsTheme};
 //! let old = "The quick brown fox and\njumps over the sleepy dog";
 //! let new = "The quick red fox and\njumps over the lazy dog";
 //! let mut buffer: Vec<u8> = Vec::new();
-//! diff(&mut buffer, old, new, arrows_theme()).unwrap();
+//! let theme = ArrowsTheme::default();
+//! diff(&mut buffer, old, new, &theme).unwrap();
 //! let actual: String = String::from_utf8(buffer).expect("Not valid UTF-8");
 //!
 //! assert_eq!(
@@ -25,10 +26,11 @@
 //! might want to use the displayable instead
 //!
 //! ```
-//! use termdiff::{signs_theme, DrawDiff};
+//! use termdiff::{DrawDiff, SignsTheme};
 //! let old = "The quick brown fox and\njumps over the sleepy dog";
 //! let new = "The quick red fox and\njumps over the lazy dog";
-//! let actual = format!("{}", DrawDiff::new(old, new, signs_theme()));
+//! let theme = SignsTheme::default();
+//! let actual = format!("{}", DrawDiff::new(old, new, &theme));
 //!
 //! assert_eq!(
 //!     actual,
@@ -45,26 +47,57 @@
 //!
 //!
 //! ``` rust
-//! use termdiff::DrawDiff;
-//! use termdiff::Theme;
+//! use std::borrow::Cow;
+//!
 //! use crossterm::style::Stylize;
+//! use termdiff::{DrawDiff, Theme};
 //!
-//! let my_theme = Theme {
-//! header: format!("{}\n", "Header"),
-//! highlight_insert: crossterm::style::Stylize::stylize,
-//! highlight_delete: crossterm::style::Stylize::stylize,
-//! equal_prefix: "=".to_string(),
-//! equal_content: crossterm::style::Stylize::stylize,
-//! delete_prefix: "!".to_string(),
-//! delete_content: crossterm::style::Stylize::stylize,
-//! insert_prefix: "|".to_string(),
-//! insert_line: crossterm::style::Stylize::stylize,
-//! line_end: "\n".into(),
-//! };
+//! struct MyTheme {}
+//! impl Theme for MyTheme {
+//!     fn highlight_insert<'this>(&self, input: &'this str) -> Cow<'this, str> {
+//!         input.into()
+//!     }
 //!
+//!     fn highlight_delete<'this>(&self, input: &'this str) -> Cow<'this, str> {
+//!         input.into()
+//!     }
+//!
+//!     fn equal_content<'this>(&self, input: &'this str) -> Cow<'this, str> {
+//!         input.into()
+//!     }
+//!
+//!     fn delete_content<'this>(&self, input: &'this str) -> Cow<'this, str> {
+//!         input.into()
+//!     }
+//!
+//!     fn equal_prefix<'this>(&self) -> Cow<'this, str> {
+//!         "=".into()
+//!     }
+//!
+//!     fn delete_prefix<'this>(&self) -> Cow<'this, str> {
+//!         "!".into()
+//!     }
+//!
+//!     fn insert_line<'this>(&self, input: &'this str) -> Cow<'this, str> {
+//!         input.into()
+//!     }
+//!
+//!     fn insert_prefix<'this>(&self) -> Cow<'this, str> {
+//!         "|".into()
+//!     }
+//!
+//!     fn line_end<'this>(&self) -> Cow<'this, str> {
+//!         "\n".into()
+//!     }
+//!
+//!     fn header<'this>(&self) -> Cow<'this, str> {
+//!         format!("{}\n", "Header").into()
+//!     }
+//! }
+//! let my_theme = MyTheme {};
 //! let old = "The quick brown fox and\njumps over the sleepy dog";
 //! let new = "The quick red fox and\njumps over the lazy dog";
-//! let actual = format!("{}", DrawDiff::new(old, new, my_theme));
+//! let actual = format!("{}", DrawDiff::new(old, new, &my_theme));
 //!
 //! assert_eq!(
 //!     actual,
@@ -83,7 +116,7 @@ mod themes;
 
 pub use cmd::diff;
 pub use draw_diff::DrawDiff;
-pub use themes::{arrows_color_theme, arrows_theme, signs_color_theme, signs_theme, Theme};
+pub use themes::{ArrowsColorTheme, ArrowsTheme, SignsColorTheme, SignsTheme, Theme};
 
 #[cfg(doctest)]
 mod test_readme {
